@@ -36,21 +36,16 @@ public class FontPicker extends Button {
 	 * Creates a new font picker.
 	 */
 	public FontPicker() {
-		noopInit();
+		super(gnome_font_picker_new());
+		initializeEventHandlers();
 	}
 
 	/**
 	 * Construct a FontPicker using a handle to a native resource.
 	 */
 	public FontPicker(int handle) {
-		setHandle(handle);
-	}
-
-	protected void noopInit() {
-		if (-1 == getHandle()) {
-			setHandle(gnome_font_picker_new());
-			initializeEventHandlers();
-		}
+		super(handle);
+		initializeEventHandlers();
 	}
 
 	/**
@@ -220,16 +215,23 @@ public class FontPicker extends Button {
 	}
 
 	protected void initializeEventHandlers() {
-		super.initializeEventHandlers();
-		evtMap.initialize(this);
+		if (!eventsInitialized) {
+			super.initializeEventHandlers();
+			evtMap.initialize(this);
+			eventsInitialized = true;
+		}
 	}
 
 	public Class getEventListenerClass(String signal) {
-		return evtMap.getListenerClass(signal);
+		Class cls = evtMap.getEventListenerClass(signal);
+		if (cls == null) cls = super.getEventListenerClass(signal);
+		return cls;
 	}
 
 	public GtkEventType getEventType(String signal) {
-		return evtMap.getEventType(signal);
+		GtkEventType et = evtMap.getEventType(signal);
+		if (et == null) et = super.getEventType(signal);
+		return et;
 	}
 
 	private static EventMap evtMap = new EventMap();
